@@ -17,4 +17,4 @@ if not os.path.exists(dstdir):
         os.makedirs(dstdir)
 
 with open(dst, 'wb') as f:
-	cPickle.dump(db, f)
+	cPickle.dump(db, f, protocol=2)
